Skip to contents

Process MSE simulations for average age of an individual fish in the population. This is distinct from the performance metric of the same name in that include both male and female fish in the calculation of average age.

Usage

get_average_age(model_runs, extra_columns, hcr_filter, om_filter)

Arguments

model_runs

list of completed MSE simulation objects

extra_columns

additional columns to append to output

hcr_filter

vector of HCR names to process (must match names in `extra_columns`)

om_filter

vector of OM names to process (must match names in `extra_columns`)