Skip to contents

Process MSE simulations for dynamic economic value (Goethel et al. 2025). Economic value calculated as a linear adjustment in price by size grade between a max price achieved at low total landings and a min price achieved at high total landings. Value is calculated only for the Fixed gear fleet.

Usage

get_dynamic_economic_value(model_runs, extra_columns, hcr_filter, om_filter)

Arguments

model_runs

list of completed MSE simulation objects

extra_columns

additional columns to append to output

hcr_filter

vector of HCR names to process (must match names in `extra_columns`)

om_filter

vector of OM names to process (must match names in `extra_columns`)