Plot Trajectory of Dynamic Economic Value
plot_dynamic_economic_value.RdPlot median trajectory of economic value for the fixed gear fleet across all simulations as a line plot. See `get_dynamic_economic_value()` for details on how economic value is calculated.
Usage
plot_dynamic_economic_value(
data,
v1 = "hcr",
v2 = NA,
v3 = NA,
common_trajectory = 54,
interval_widths = c(0.5, 0.8),
base_hcr = "F40",
highlight = NULL,
relative = NA
)Arguments
- data
tibble output from `get_dynamic_economic_value()`
- v1
variable to map to color (e.g. "hcr")
- v2
variable to facet by (e.g. "om")
- v3
variable to facet by in addition to v2 (e.g. "om")
- common_trajectory
year to plot vertical dashed line to indicate where MSE projection period begins
- base_hcr
HCR to plot as a thicker line for reference (must match names in `extra_columns`)
- highlight
vector of HCRs to highlight with color (must match names in `extra_columns`)
- relative
whether to relativize economic value to a specific HCR (must match names in `extra_columns`)