Skip to contents

Plot median trajectory of total fishing mortality across all simulations as a line plot.

Usage

plot_fishing_mortalities(
  data,
  v1 = "hcr",
  v2 = NA,
  v3 = NA,
  show_est = FALSE,
  common_trajectory = 64,
  interval_widths = c(0.5, 0.8),
  base_hcr = "F40",
  highlight = NULL
)

Arguments

data

tibble output from `get_fishing_mortalities()`

v1

variable to map to color (e.g. "hcr")

v2

variable to facet by (e.g. "om")

v3

variable to facet by in addition to v2 (e.g. "om")

show_est

whether to show estimated SSB from EM as point ranges

common_trajectory

year to plot vertical dashed line to indicate where MSE projection period begins

base_hcr

HCR to plot as a thicker line for reference (must match names in `extra_columns`)

highlight

vector of HCRs to highlight with color (must match names in `extra_columns`)