Skip to contents

Plot summary of performance metrics across all simulation as point intervals.

Usage

plot_performance_metric_summary(
  perf_data,
  v1 = "hcr",
  v2 = "om",
  is_relative = FALSE,
  highlight = NULL
)

Arguments

perf_data

tibble output from `performance_metric_summary()`

v1

variable to map to y-axis (e.g. "hcr")

v2

variable to facet by (e.g. "om")

is_relative

whether the performance metrics have been relativized to a specific HCR

highlight

vector of HCRs to highlight with color (must match names in `extra_columns`)