Plot Trajectories of Spawning Biomass and Landed Catch
plot_ssb_catch.RdPlot median trajectory of total landed catch and SSB across all simulations as line plots.
Usage
plot_ssb_catch(
ssb_data,
catch_data,
v1 = "hcr",
v2 = NA,
v3 = NA,
common_trajectory = 64,
base_hcr = "F40",
flip_facet = FALSE,
highlight = NULL
)Arguments
- ssb_data
tibble output from `get_ssb_biomass()`
- catch_data
tibble output from `get_landed_catch()`
- v1
variable to map to color (e.g. "hcr")
- v2
variable to facet by (e.g. "om")
- v3
variable to facet by in addition to v2 (e.g. "om")
- common_trajectory
year to plot vertical dashed line to indicate where MSE projection period begins
- base_hcr
HCR to plot as a thicker line for reference (must match names in `extra_columns`)
- highlight
vector of HCRs to highlight with color (must match names in `extra_columns`)