Skip to contents

General function for plotting timeseries of management quantities (e.g. SSB, catch, ABC, TAC) with options for faceting and highlighting specific HCRs.

Usage

plot_timeseries(
  data,
  v1 = "hcr",
  v2 = NA,
  v3 = NA,
  common_trajectory = 54,
  interval_widths = c(0.5, 0.8),
  base_hcr = "F40",
  ylab = "",
  highlight = NULL
)

Arguments

data

tibble summarised with `median_qi()` and reformatted with `reformat_ggdist_long()`

v1

variable to map to color (e.g. "hcr")

v2

variable to facet by (e.g. "om")

v3

variable to facet by in addition to v2 (e.g. "om")

common_trajectory

year to plot vertical dashed line to indicate where MSE projection period begins

interval_widths

vector of credible interval widths to plot (e.g. c(0.50, 0.80))

base_hcr

HCR to plot as a thicker line for reference (must match names in `extra_columns`)

ylab

label for y-axis

highlight

vector of HCRs to highlight with color (must match names in `extra_columns`)