Plot Trajectories of ABC, TAC, Expected Landings, and Attainment
plot_abc_tac.RdPlot median trajectory of management quantitoes across all simulations as line plots.
Usage
plot_abc_tac(
data,
v1 = "hcr",
v2 = NA,
common_trajectory = 64,
interval_widths = c(0.5, 0.8),
base_hcr = "F40",
highlight = NULL
)Arguments
- data
tibble output from `get_management_quantities()`
- v1
variable to map to color (e.g. "hcr")
- v2
variable to facet by (e.g. "om")
- common_trajectory
year to plot vertical dashed line to indicate where MSE projection period begins
- base_hcr
HCR to plot as a thicker line for reference (must match names in `extra_columns`)
- highlight
vector of HCRs to highlight with color (must match names in `extra_columns`)
- v3
variable to facet by in addition to v2 (e.g. "om")