Plot Trajectory of Landed Catch
plot_landed_catch.RdPlot median trajectory of total landed catch across all simulations as a line plot.
Usage
plot_landed_catch(
data,
v1 = "hcr",
v2 = NA,
v3 = NA,
by_fleet = FALSE,
common_trajectory = 64,
base_hcr = "F40",
highlight = NULL
)Arguments
- data
tibble output from `get_landed_catch()`
- v1
variable to map to color (e.g. "hcr")
- v2
variable to facet by (e.g. "om")
- v3
variable to facet by in addition to v2 (e.g. "om")
- common_trajectory
year to plot vertical dashed line to indicate where MSE projection period begins
- base_hcr
HCR to plot as a thicker line for reference (must match names in `extra_columns`)
- highlight
vector of HCRs to highlight with color (must match names in `extra_columns`)