Relativize Performance Values to a Specific Referecnce HCR
relativize_performance.RdConvert raw performance metric values to relative performance values by dividing by the performance metric value for a specific reference HCR. This allows for easier comparison of performance across HCRs, as the relative performance values will be on a common scale.
Arguments
- data
a tibble of performance metric data
- rel_column
the name of the column containing HCR names
- value_column
the name of the column containing performance metric values
- rel_value
the name of the reference HCR to relativize to
- grouping
a vector of column names to group by when relativizing (e.g. "om", "time", "sim")